@@ -3,7 +3,6 @@
 # Standard Library
 # pylint: disable=too-many-public-methods
 import os
-import signal
 from gettext import gettext as _
 
 from gi.repository import Gio
@@ -14,7 +13,7 @@ from lutris.gui import dialogs
 from lutris.gui.config.add_game import AddGameDialog
 from lutris.gui.config.edit_game import EditGameConfigDialog
 from lutris.gui.dialogs.log import LogWindow
-from lutris.gui.dialogs.uninstall_game import UninstallGameDialog
+from lutris.gui.dialogs.uninstall_game import RemoveGameDialog, UninstallGameDialog
 from lutris.gui.widgets.utils import open_uri
 from lutris.util import xdgshortcuts
 from lutris.util.log import LOG_BUFFERS, logger
@@ -22,7 +21,6 @@ from lutris.util.system import path_exists
 
 
 class GameActions:
-
     """Regroup a list of callbacks for a game"""
 
     def __init__(self, application=None, window=None):
@@ -122,9 +120,9 @@ class GameActions:
                 self.game.is_installed
                 and xdgshortcuts.menu_launcher_exists(self.game.slug, self.game.id)
             ),
-            "remove": self.game.is_installed,
+            "remove": True,
             "view": True,
-            "hide": not self.game.is_hidden,
+            "hide": self.game.is_installed and not self.game.is_hidden,
             "unhide": self.game.is_hidden,
         }
 
@@ -139,22 +137,15 @@ class GameActions:
                 return self.game
         logger.warning("Game %s not in %s", self.game_id, ids)
 
-    def on_game_stop(self, caller):  # pylint: disable=unused-argument
+    def on_game_stop(self, _caller):
         """Stops the game"""
-        matched_game = self.get_running_game()
-        if not matched_game:
-            return
-        if not matched_game.game_thread:
-            logger.warning("Game %s doesn't appear to be running, not killing it", self.game_id)
-            return
-        try:
-            os.kill(matched_game.game_thread.game_process.pid, signal.SIGTERM)
-        except ProcessLookupError as ex:
-            logger.debug("Failed to kill game process: %s", ex)
+        game = self.get_running_game()
+        if game:
+            game.force_stop()
 
     def on_show_logs(self, _widget):
         """Display game log"""
-        _buffer = LOG_BUFFERS.get(self.game.id)
+        _buffer = LOG_BUFFERS.get(str(self.game.id))
         if not _buffer:
             logger.info("No log for game %s", self.game)
         return LogWindow(
@@ -166,11 +157,21 @@ class GameActions:
     def on_install_clicked(self, *_args):
         """Install a game"""
         # Install the currently selected game in the UI
+        if not self.game.slug:
+            raise RuntimeError("No game to install: %s" % self.game.id)
         self.game.emit("game-install")
 
+    def on_locate_installed_game(self, _button, game):
+        """Show the user a dialog to import an existing install to a DRM free service
+
+        Params:
+            game (Game): Game instance without a database ID, populated with a fields the service can provides
+        """
+        AddGameDialog(self.window, game=game)
+
     def on_add_manually(self, _widget, *_args):
         """Callback that presents the Add game dialog"""
-        AddGameDialog(self.window, game=self.game, runner=self.game.runner_name)
+        return AddGameDialog(self.window, game=self.game, runner=self.game.runner_name)
 
     def on_edit_game_configuration(self, _widget):
         """Edit game preferences"""
@@ -186,11 +187,11 @@ class GameActions:
 
     def on_hide_game(self, _widget):
         """Add a game to the list of hidden games"""
-        self.game.hide()
+        self.game.set_hidden(True)
 
     def on_unhide_game(self, _widget):
         """Removes a game from the list of hidden games"""
-        self.game.unhide()
+        self.game.set_hidden(False)
 
     def on_execute_script_clicked(self, _widget):
         """Execute the game's associated script"""
@@ -235,4 +236,7 @@ class GameActions:
 
     def on_remove_game(self, *_args):
         """Callback that present the uninstall dialog to the user"""
-        UninstallGameDialog(game_id=self.game.id, parent=self.window)
+        if self.game.is_installed:
+            UninstallGameDialog(game_id=self.game.id, parent=self.window)
+        else:
+            RemoveGameDialog(game_id=self.game.id, parent=self.window)
