@@ -1,6 +1,6 @@
-# pylint: disable=no-member,wrong-import-position
+# pylint: disable=wrong-import-position
 #
-# Copyright (C) 2020 Mathieu Comandon <strider@strycore.com>
+# Copyright (C) 2021 Mathieu Comandon <strider@strycore.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@ import os
 import signal
 import sys
 import tempfile
+
+from datetime import datetime, timedelta
 from gettext import gettext as _
 
 import gi
@@ -41,13 +43,13 @@ from lutris.gui.dialogs.issue import IssueReportWindow
 from lutris.gui.installerwindow import InstallerWindow
 from lutris.gui.widgets.status_icon import LutrisStatusIcon
 from lutris.migrations import migrate
-from lutris.startup import init_lutris, run_all_checks
+from lutris.startup import init_lutris, run_all_checks, update_runtime
 from lutris.util import datapath, log
 from lutris.util.http import HTTPError, Request
 from lutris.util.log import logger
 from lutris.util.steam.appmanifest import AppManifest, get_appmanifests
 from lutris.util.steam.config import get_steamapps_paths
-from lutris.services import get_services
+from lutris.services import get_enabled_services
 from lutris.database.services import ServiceGameCollection
 
 from .lutriswindow import LutrisWindow
@@ -206,14 +208,17 @@ class Application(Gtk.Application):
         action.connect("activate", lambda *x: self.quit())
         self.add_action(action)
         self.add_accelerator("<Primary>q", "app.quit")
-
-        init_dialog = LutrisInitDialog(init_lutris)
+        init_lutris()
+        if os.environ.get("LUTRIS_SKIP_INIT"):
+            logger.debug("Skipping initialization")
+            return
+        init_dialog = LutrisInitDialog(update_runtime)
         init_dialog.run()
 
     def do_activate(self):  # pylint: disable=arguments-differ
         if not self.window:
             self.window = LutrisWindow(application=self)
-            screen = self.window.props.screen
+            screen = self.window.props.screen  # pylint: disable=no-member
             Gtk.StyleContext.add_provider_for_screen(screen, self.css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
         if not self.run_in_background:
             self.window.present()
@@ -222,6 +227,15 @@ class Application(Gtk.Application):
             # accordingly
             self.run_in_background = False
 
+    def get_window_key(self, **kwargs):
+        if kwargs.get("appid"):
+            return kwargs["appid"]
+        if kwargs.get("runner"):
+            return kwargs["runner"].name
+        if kwargs.get("installers"):
+            return kwargs["installers"][0]["game_slug"]
+        return str(kwargs)
+
     def show_window(self, window_class, **kwargs):
         """Instanciate a window keeping 1 instance max
 
@@ -232,7 +246,7 @@ class Application(Gtk.Application):
         Returns:
             Gtk.Window: the existing window instance or a newly created one
         """
-        window_key = str(window_class) + str(kwargs)
+        window_key = str(window_class) + self.get_window_key(**kwargs)
         if self.app_windows.get(window_key):
             self.app_windows[window_key].present()
             return self.app_windows[window_key]
@@ -240,8 +254,10 @@ class Application(Gtk.Application):
             window_inst = window_class(parent=self.window, **kwargs)
         else:
             window_inst = window_class(application=self, **kwargs)
-        window_inst.connect("destroy", self.on_app_window_destroyed, str(kwargs))
+        window_inst.connect("destroy", self.on_app_window_destroyed, self.get_window_key(**kwargs))
         self.app_windows[window_key] = window_inst
+        logger.debug("Showing window %s", window_key)
+        window_inst.show()
         return window_inst
 
     def show_installer_window(self, installers, service=None, appid=None):
@@ -252,13 +268,15 @@ class Application(Gtk.Application):
             appid=appid
         )
 
-    def on_app_window_destroyed(self, app_window, kwargs_str):
+    def on_app_window_destroyed(self, app_window, window_key):
         """Remove the reference to the window when it has been destroyed"""
-        window_key = str(app_window.__class__) + kwargs_str
+        window_key = str(app_window.__class__) + window_key
         try:
             del self.app_windows[window_key]
+            logger.debug("Removed window %s", window_key)
         except KeyError:
-            pass
+            logger.warning("Failed to remove window %s", window_key)
+            logger.info("Available windows: %s", ", ".join(self.app_windows.keys()))
         return True
 
     @staticmethod
@@ -312,7 +330,6 @@ class Application(Gtk.Application):
             logger.setLevel(logging.NOTSET)
             return 0
 
-        logger.info("Lutris %s", settings.VERSION)
         migrate()
         run_all_checks()
 
@@ -472,12 +489,25 @@ class Application(Gtk.Application):
 
     def on_game_install(self, game):
         """Request installation of a game"""
-        if game.service:
-            service = get_services()[game.service]()
+        if game.service and game.service != "lutris":
+            service = get_enabled_services()[game.service]()
             db_game = ServiceGameCollection.get_game(service.id, game.appid)
-            service.install(db_game)
-            return True
 
+            try:
+                game_id = service.install(db_game)
+            except ValueError as e:
+                logger.debug(e)
+                game_id = None
+
+            if game_id:
+                game = Game(game_id)
+                game.launch()
+            else:
+                ErrorDialog(message=_("Could not retrieve game installer."), parent=self.window)
+            return True
+        if not game.slug:
+            raise ValueError("Invalid game passed: %s" % game)
+            # return True
         installers = get_installers(game_slug=game.slug)
         if installers:
             self.show_installer_window(installers)
@@ -554,6 +584,9 @@ class Application(Gtk.Application):
                 "name": game["name"],
                 "runner": game["runner"],
                 "platform": game["platform"],
+                "year": game["year"],
+                "playtime": str(timedelta(hours=game["playtime"])),
+                "lastplayed": str(datetime.fromtimestamp(game["lastplayed"])),
                 "directory": game["directory"],
             } for game in game_list
         ]
