@@ -145,7 +145,7 @@ class ConfigBox(VBox):
             if option.get("advanced"):
                 hbox.get_style_context().add_class("advanced")
                 show_advanced = settings.read_setting("show_advanced_options")
-                if not show_advanced == "True":
+                if show_advanced != "True":
                     hbox.set_no_show_all(True)
             hbox.pack_start(self.wrapper, True, True, 0)
             self.pack_start(hbox, False, False, 0)
@@ -393,7 +393,7 @@ class ConfigBox(VBox):
             path=path,
             default_path=default_path
         )
-        file_chooser.set_size_request(200, 30)
+        # file_chooser.set_size_request(200, 30)
 
         if "default_path" in option:
             default_path = self.lutris_config.system_config.get(option["default_path"])
