@@ -1,7 +1,5 @@
-# Third Party Libraries
 import gi
 
-# Lutris Modules
 from lutris.util.log import logger
 
 NOTIFY_SUPPORT = True
@@ -14,7 +12,7 @@ except ImportError:
 if NOTIFY_SUPPORT:
     Notify.init("lutris")
 else:
-    logger.warning("Notifications are disabled, please install" " GObject bindings for 'Notify' to enable them.")
+    logger.warning("Notifications are disabled, please install GObject bindings for 'Notify' to enable them.")
 
 
 def send_notification(title, text, file_path_to_icon="lutris"):
