@@ -20,7 +20,7 @@ from lutris.util.display import DISPLAY_MANAGER
 from lutris.util.jobs import AsyncCall
 from lutris.util.log import logger
 from lutris.util.strings import unpack_dependencies
-from lutris.util.wine.wine import get_system_wine_version, get_wine_version_exe
+from lutris.util.wine.wine import get_wine_version, get_wine_version_exe
 
 
 class ScriptInterpreter(GObject.Object, CommandsMixin):
@@ -88,10 +88,6 @@ class ScriptInterpreter(GObject.Object, CommandsMixin):
             self.installer.script.get('system', {}).get('env', {}).items()
         }
 
-    # --------------------------
-    # "Initial validation" stage
-    # --------------------------
-
     @staticmethod
     def _get_installed_dependency(dependency):
         """Return whether a dependency is installed"""
@@ -191,8 +187,6 @@ class ScriptInterpreter(GObject.Object, CommandsMixin):
         runners_to_install = []
         required_runners = []
         runner = self.get_runner_class(self.installer.runner)
-        if runner.depends_on is not None:
-            required_runners.append(runner.depends_on())
         required_runners.append(runner())
 
         for command in self.installer.script.get("installer", []):
@@ -235,7 +229,7 @@ class ScriptInterpreter(GObject.Object, CommandsMixin):
                 logger.info("Runner %s needs to be installed", runner)
                 runners_to_install.append(runner)
 
-        if self.installer.runner.startswith("wine") and not get_system_wine_version():
+        if self.installer.runner.startswith("wine") and not get_wine_version():
             WineNotInstalledWarning(parent=self.parent)
         return runners_to_install
 
@@ -392,7 +386,9 @@ class ScriptInterpreter(GObject.Object, CommandsMixin):
             "RESOLUTION": "x".join(self.current_resolution),
             "RESOLUTION_WIDTH": self.current_resolution[0],
             "RESOLUTION_HEIGHT": self.current_resolution[1],
+            "WINEBIN": self.get_wine_path(),
         }
+        replacements.update(self.installer.variables)
         # Add 'INPUT_<id>' replacements for user inputs with an id
         for input_data in self.user_inputs:
             alias = input_data["alias"]
