@@ -5,12 +5,12 @@ import time
 
 from gi.repository import GLib
 
-from lutris.settings import RUNTIME_DIR, RUNTIME_URL
+from lutris import settings
 from lutris.util import http, jobs, system
 from lutris.util.downloader import Downloader
 from lutris.util.extract import extract_archive
+from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import logger
-from lutris.util.system import LINUX_SYSTEM
 
 RUNTIME_DISABLED = os.environ.get("LUTRIS_RUNTIME", "").lower() in ("0", "off")
 DEFAULT_RUNTIME = "Ubuntu-18.04"
@@ -29,7 +29,7 @@ class Runtime:
         """Return the local path for the runtime folder"""
         if not self.name:
             return None
-        return os.path.join(RUNTIME_DIR, self.name)
+        return os.path.join(settings.RUNTIME_DIR, self.name)
 
     def get_updated_at(self):
         """Return the modification date of the runtime folder"""
@@ -64,7 +64,7 @@ class Runtime:
 
     def should_update_component(self, filename, remote_modified_at):
         """Should an individual component be updated?"""
-        file_path = os.path.join(RUNTIME_DIR, self.name, filename)
+        file_path = os.path.join(settings.RUNTIME_DIR, self.name, filename)
         if not system.path_exists(file_path):
             return True
         locally_modified_at = time.gmtime(os.path.getmtime(file_path))
@@ -82,7 +82,7 @@ class Runtime:
         if not self.should_update(remote_updated_at):
             return None
 
-        archive_path = os.path.join(RUNTIME_DIR, os.path.basename(url))
+        archive_path = os.path.join(settings.RUNTIME_DIR, os.path.basename(url))
         downloader = Downloader(url, archive_path, overwrite=True)
         downloader.start()
         GLib.timeout_add(100, self.check_download_progress, downloader)
@@ -90,16 +90,17 @@ class Runtime:
 
     def download_component(self, component):
         """Download an individual file from a runtime item"""
-        file_path = os.path.join(RUNTIME_DIR, self.name, component["filename"])
+        file_path = os.path.join(settings.RUNTIME_DIR, self.name, component["filename"])
         try:
             http.download_file(component["url"], file_path)
-        except http.HTTPError:
+        except http.HTTPError as ex:
+            logger.error("Failed to download runtime component %s: %s", component, ex)
             return
         return file_path
 
     def get_runtime_components(self):
         """Fetch runtime components from the API"""
-        request = http.Request(RUNTIME_URL + "/" + self.name)
+        request = http.Request(settings.RUNTIME_URL + "/" + self.name)
         try:
             response = request.get()
         except http.HTTPError as ex:
@@ -152,6 +153,12 @@ class Runtime:
         Arguments:
             path (str): local path to the runtime archive
         """
+        stats = os.stat(path)
+        if not stats.st_size:
+            logger.error("Download failed: file %s is empty, Deleting file.", path)
+            os.unlink(path)
+            self.updater.notify_finish(self)
+            return False
         directory, _filename = os.path.split(path)
 
         # Delete the existing runtime path
@@ -159,7 +166,7 @@ class Runtime:
         system.remove_folder(initial_path)
 
         # Extract the runtime archive
-        jobs.AsyncCall(extract_archive, self.on_extracted, path, RUNTIME_DIR, merge_single=False)
+        jobs.AsyncCall(extract_archive, self.on_extracted, path, settings.RUNTIME_DIR, merge_single=False)
         return False
 
     def on_extracted(self, result, error):
@@ -167,6 +174,7 @@ class Runtime:
         if error:
             logger.error("Runtime update failed")
             logger.error(error)
+            self.updater.notify_finish(self)
             return False
         archive_path, _destination_path = result
         logger.debug("Deleting runtime archive %s", archive_path)
@@ -189,7 +197,7 @@ class RuntimeUpdater:
     def update(self):
         """Launch the update process"""
         if RUNTIME_DISABLED:
-            logger.debug("Runtime disabled, not updating it.")
+            logger.warning("Runtime disabled, not updating it.")
             return 0
 
         for remote_runtime in self._iter_remote_runtimes():
@@ -201,7 +209,7 @@ class RuntimeUpdater:
 
     @staticmethod
     def _iter_remote_runtimes():
-        request = http.Request(RUNTIME_URL)
+        request = http.Request(settings.RUNTIME_URL + "?enabled=1")
         try:
             response = request.get()
         except http.HTTPError as ex:
@@ -212,7 +220,7 @@ class RuntimeUpdater:
 
             # Skip 32bit runtimes on 64 bit systems except the main runtime
             if (
-                runtime["architecture"] == "i386" and system.LINUX_SYSTEM.is_64_bit
+                runtime["architecture"] == "i386" and LINUX_SYSTEM.is_64_bit
                 and not runtime["name"].startswith(("Ubuntu", "lib32"))
             ):
                 logger.debug(
@@ -223,7 +231,7 @@ class RuntimeUpdater:
                 continue
 
             # Skip 64bit runtimes on 32 bit systems
-            if runtime["architecture"] == "x86_64" and not system.LINUX_SYSTEM.is_64_bit:
+            if runtime["architecture"] == "x86_64" and not LINUX_SYSTEM.is_64_bit:
                 logger.debug(
                     "Skipping runtime %s for %s",
                     runtime["name"],
@@ -242,7 +250,7 @@ class RuntimeUpdater:
 
 
 def get_env(version=None, prefer_system_libs=False, wine_path=None):
-    """Return a dict containing LD_LIBRARY_PATH and STEAM_RUNTIME env vars
+    """Return a dict containing LD_LIBRARY_PATH env var
 
     Params:
         version (str): Version of the runtime to use, such as "Ubuntu-18.04" or "legacy"
@@ -253,12 +261,9 @@ def get_env(version=None, prefer_system_libs=False, wine_path=None):
     Returns:
         dict
     """
-    # Adding the STEAM_RUNTIME here is probably unneeded and unwanted
     return {
         key: value
         for key, value in {
-            "STEAM_RUNTIME":
-            os.path.join(RUNTIME_DIR, "steam") if not RUNTIME_DISABLED else None,
             "LD_LIBRARY_PATH":
             ":".join(get_paths(version=version, prefer_system_libs=prefer_system_libs, wine_path=wine_path)),
         }.items() if value
@@ -279,13 +284,7 @@ def get_winelib_paths(wine_path):
 def get_runtime_paths(version=None, prefer_system_libs=True, wine_path=None):
     """Return Lutris runtime paths"""
     version = version or DEFAULT_RUNTIME
-    if version.startswith("Ubuntu"):
-        lutris_runtime_path = "%s-i686" % version
-    elif version == "legacy":
-        lutris_runtime_path = "lib32"
-    else:
-        raise ValueError("Invalid runtime version %s" % version)
-
+    lutris_runtime_path = "%s-i686" % version
     runtime_paths = [
         lutris_runtime_path,
         "steam/i386/lib/i386-linux-gnu",
@@ -294,11 +293,8 @@ def get_runtime_paths(version=None, prefer_system_libs=True, wine_path=None):
         "steam/i386/usr/lib",
     ]
 
-    if system.LINUX_SYSTEM.is_64_bit:
-        if version == "legacy":
-            lutris_runtime_path = "lib64"
-        else:
-            lutris_runtime_path = "%s-x86_64" % version
+    if LINUX_SYSTEM.is_64_bit:
+        lutris_runtime_path = "%s-x86_64" % version
         runtime_paths += [
             lutris_runtime_path,
             "steam/amd64/lib/x86_64-linux-gnu",
@@ -313,7 +309,7 @@ def get_runtime_paths(version=None, prefer_system_libs=True, wine_path=None):
             paths += get_winelib_paths(wine_path)
         paths += list(LINUX_SYSTEM.iter_lib_folders())
     # Then resolve absolute paths for the runtime
-    paths += [os.path.join(RUNTIME_DIR, path) for path in runtime_paths]
+    paths += [os.path.join(settings.RUNTIME_DIR, path) for path in runtime_paths]
     return paths
 
 
@@ -323,6 +319,7 @@ def get_paths(version=None, prefer_system_libs=True, wine_path=None):
         paths = get_runtime_paths(version=version, prefer_system_libs=prefer_system_libs, wine_path=wine_path)
     else:
         paths = []
+    # Put existing LD_LIBRARY_PATH at the end
     if os.environ.get("LD_LIBRARY_PATH"):
         paths.append(os.environ["LD_LIBRARY_PATH"])
     return paths
