@@ -7,20 +7,20 @@ gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 from lutris.database import games as games_db
 from lutris.game import Game
-from lutris.startup import init_lutris
 # from lutris import settings
 from lutris.gui.config.common import GameDialogCommon
 from lutris.gui.config.add_game import AddGameDialog
 from lutris.gui.application import Application
 from lutris.gui.views.store import sort_func
+from lutris.util.test_config import setup_test_environment
 from lutris import runners
 
-TEST_PGA_PATH = os.path.join(os.path.dirname(__file__), 'pga.db')
+setup_test_environment()
 
 
 class TestGameDialogCommon(TestCase):
     def test_get_runner_liststore(self):
-        dlg = GameDialogCommon()
+        dlg = GameDialogCommon("test")
         list_store = dlg._get_runner_liststore()
         self.assertTrue(
             list_store[1][0].startswith(runners.get_installed()[0].human_name)
@@ -30,7 +30,6 @@ class TestGameDialogCommon(TestCase):
 
 class TestGameDialog(TestCase):
     def setUp(self):
-        init_lutris()
         lutris_application = Application()
         lutris_window = lutris_application.window
         self.dlg = AddGameDialog(lutris_window)
